## Name
Oxpecker CLI.

## Description
CLI of Oxpecker service.

## Installation
开发环境推荐：Editable模式（安装目录链接到源码目录）：
```sh
pip install -e .
```

生产环境推荐：构建wheel包再安装：
```sh
pip install build
python -m build --wheel
pip install dist/oxpecker-<version>-py3-none-any.whl
```

## Usage
```sh
oxpecker --help
```
## Development


## Roadmap
None yet.

## Project status
Alpha.
